==> kadu_0.10.1.orig.tar.bz2: kadu-0.10.1/plugins/sms/translations/sms_en.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="en_US">
<context>
    <name>@default</name>
    <message>
        <source>SMS</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>General</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Nick</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>SMS Nick</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Application</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Use built-in SMS application</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Custom SMS application</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Use SMS custom string</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>SMS custom string</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Gateways</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Shortcuts</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Send SMS</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
		<source>SMS T-Mobile.pl Gateway</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sponsored</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>OmnixMultimedia</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Orange Multibox</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>User ID (48xxxxxxxxx)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Password</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Check this box if your sms application does not understand arguments: number &amp;message&amp;
Arguments should be separated with spaces. %k argument is converted to number, %m to message</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SmsActions</name>
    <message>
        <source>Send SMS...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SmsDialog</name>
    <message>
        <source>Send SMS</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Recipient</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select automatically</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>GSM provider</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Content</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Signature</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save SMS in history</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Send</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Close</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Clear</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Kadu</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>SMS application was not specified. Visit the configuration section</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SmsExternalSender</name>
    <message>
        <source>Could not spawn child process. Check if the program is functional</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The process exited abnormally. The SMS may not be sent</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SmsImageDialog</name>
    <message>
        <source>Enter text from the picture:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ok</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>SMS</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to fetch required token</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SmsInternalSender</name>
    <message>
        <source>Mobile number is incorrect</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Signature can&apos;t be empty</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Automatic gateway selection is not available. Please select SMS gateway manually.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SmsProgressWindow</name>
    <message>
        <source>Sending SMS in progress.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enter text from the picture:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ok</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>SMS sent successfully</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> kadu_0.11.2.orig.tar.bz2: kadu-0.11.2/plugins/sms/translations/sms_en.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="en_US">
<context>
    <name>@default</name>
    <message>
        <source>SMS</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>General</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>SMS Nick</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Application</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Use built-in SMS application</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Custom SMS application</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Use SMS custom string</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>SMS custom string</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Gateways</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Shortcuts</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Send SMS</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>SMS T-Mobile.pl Gateway</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sponsored</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>OmnixMultimedia</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Orange Multibox</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>User ID (48xxxxxxxxx)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Password</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Check this box if your sms application does not understand arguments: number &amp;message&amp;
Arguments should be separated with spaces. %k argument is converted to number, %m to message</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>SMS proxy for built-in application</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SmsActions</name>
    <message>
        <source>Send SMS...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SmsDialog</name>
    <message>
        <source>Send SMS</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Recipient</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select automatically</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>GSM provider</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Content</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Signature</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save SMS in history</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Send</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Close</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Clear</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Kadu</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>SMS application was not specified. Visit the configuration section</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SmsExternalSender</name>
    <message>
        <source>Could not spawn child process. Check if the program is functional</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The process exited abnormally. The SMS may not be sent</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SmsImageDialog</name>
    <message>
        <source>Enter text from the picture:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ok</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>SMS</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to fetch required token</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SmsInternalSender</name>
    <message>
        <source>Signature can&apos;t be empty</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Automatic gateway selection is not available. Please select SMS gateway manually.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SmsProgressWindow</name>
    <message>
        <source>Sending SMS in progress.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enter text from the picture:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ok</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>SMS sent successfully</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
